"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseSelectAll = exports.parseSelectExpressionOrList = void 0;
const object_utils_js_1 = require("../util/object-utils.js");
const selection_node_js_1 = require("../operation-node/selection-node.js");
const reference_parser_js_1 = require("./reference-parser.js");
const dynamic_reference_builder_js_1 = require("../dynamic/dynamic-reference-builder.js");
const complex_expression_parser_js_1 = require("./complex-expression-parser.js");
function parseSelectExpressionOrList(ctx, selection) {
    if ((0, object_utils_js_1.isReadonlyArray)(selection)) {
        return selection.map((it) => parseSelectExpression(ctx, it));
    }
    else {
        return [parseSelectExpression(ctx, selection)];
    }
}
exports.parseSelectExpressionOrList = parseSelectExpressionOrList;
function parseSelectExpression(ctx, selection) {
    if ((0, object_utils_js_1.isString)(selection)) {
        return selection_node_js_1.SelectionNode.create((0, reference_parser_js_1.parseAliasedStringReference)(selection));
    }
    else if ((0, dynamic_reference_builder_js_1.isDynamicReferenceBuilder)(selection)) {
        return selection_node_js_1.SelectionNode.create(selection.toOperationNode());
    }
    else {
        return selection_node_js_1.SelectionNode.create((0, complex_expression_parser_js_1.parseAliasedComplexExpression)(ctx, selection));
    }
}
function parseSelectAll(table) {
    if (!table) {
        return [selection_node_js_1.SelectionNode.createSelectAll()];
    }
    else if (Array.isArray(table)) {
        return table.map(parseSelectAllArg);
    }
    else {
        return [parseSelectAllArg(table)];
    }
}
exports.parseSelectAll = parseSelectAll;
function parseSelectAllArg(table) {
    if ((0, object_utils_js_1.isString)(table)) {
        return selection_node_js_1.SelectionNode.createSelectAllFromTable(table);
    }
    throw new Error(`invalid value selectAll expression: ${JSON.stringify(table)}`);
}
